From b4f8838b15342670c31753a484abf0129e3c9653 Mon Sep 17 00:00:00 2001
From: jcduff <jcduff@localhost>
Date: Thu, 23 Oct 2008 14:04:24 +0000
Subject: [PATCH] The commit will bring the following features : - An updated version of the underlying database. BDB JE 3.3 is now used. - Attribute API refactoring providing a better abstraction and offering improved performances. - A new GUI called the Control-Panel to replace the Status-Panel: the specifications for this GUI are available on OpenDS Wiki and contains a link to a mockup. See <https://www.opends.org/wiki/page/ControlPanelUISpecification>. - Some changes in the replication protocol to implement "Assured Replication Mode". The specifications are on OpenDS Wiki at <https://www.opends.org/wiki/page/AssuredMode> and section 7 described some of the replication changes required to support this. Assured Replication is not finished, but the main replication protocol changes to support it are done. As explained by Gilles on an email on the Dev mailing list (http://markmail.org/message/46rgo3meq3vriy4a), with these changes the newer versions of OpenDS may not be able to replicate with OpenDS 1.0 instances. - Support for Service Tags on the platforms where the functionality is available and enabled. Specifications are published at <https://www.opends.org/wiki/page/OpenDSServiceTagEnabled>. For more information on Service Tags see <http://wikis.sun.com/display/ServiceTag/Sun+Service+Tag+FAQ>. - The Admin Connector service. In order to provide agentry of the OpenDS server at any time, a new service has been added, dedicated to the administration, configuration and monitoring of the server. An overview of the Admin Connector service and it's use is available on the OpenDS wiki <https://www.opends.org/wiki/page/ManagingAdministrationTrafficToTheServer> - Updates to the various command line tools to support the Admin Connector service. - Some internal re-architecting of the server to put the foundation of future developments such as virtual directory services. The new NetworkGroups and WorkFlow internal services which have been specified in <https://www.opends.org/wiki/page/BasicOperationRoutingThroughNetworkGroup> are now implemented. - Many bug fixes...
---
opendj-sdk/opends/src/server/org/opends/server/replication/protocol/SocketSession.java | 22 ++++++++++++++++------
1 files changed, 16 insertions(+), 6 deletions(-)
diff --git a/opendj-sdk/opends/src/server/org/opends/server/replication/protocol/SocketSession.java b/opendj-sdk/opends/src/server/org/opends/server/replication/protocol/SocketSession.java
index cbfc3c8..dbe3893 100644
--- a/opendj-sdk/opends/src/server/org/opends/server/replication/protocol/SocketSession.java
+++ b/opendj-sdk/opends/src/server/org/opends/server/replication/protocol/SocketSession.java
@@ -41,7 +41,7 @@
/**
* This class Implement a protocol session using a basic socket and relying on
* the innate encoding/decoding capabilities of the ReplicationMessage
* by using the getBytes() and generateMsg() methods of those classes.
*/
public class SocketSession implements ProtocolSession
@@ -101,10 +101,19 @@
/**
* {@inheritDoc}
*/
- public synchronized void publish(ReplicationMessage msg)
+ public synchronized void publish(ReplicationMsg msg)
throws IOException
{
- byte[] buffer = msg.getBytes();
+ publish(msg, ProtocolVersion.getCurrentVersion());
+ }
+
+ /**
+ * {@inheritDoc}
+ */
+ public synchronized void publish(ReplicationMsg msg, short reqProtocolVersion)
+ throws IOException
+ {
+ byte[] buffer = msg.getBytes(reqProtocolVersion);
String str = String.format("%08x", buffer.length);
if (debugEnabled())
@@ -124,8 +133,9 @@
/**
* {@inheritDoc}
*/
- public ReplicationMessage receive() throws IOException,
- ClassNotFoundException, DataFormatException
+ public ReplicationMsg receive() throws IOException,
+ ClassNotFoundException, DataFormatException,
+ NotSupportedOldVersionPDUException
{
/* Read the first 8 bytes containing the packet length */
int length = 0;
@@ -161,7 +171,7 @@
/* We do not want the heartbeat to close the session when */
/* we are processing a message even a time consuming one. */
lastReceiveTime=0;
- return ReplicationMessage.generateMsg(buffer);
+ return ReplicationMsg.generateMsg(buffer);
}
catch (OutOfMemoryError e)
{
@@ -41,7 +41,7 @@
/**
* This class Implement a protocol session using a basic socket and relying on
- * the innate encoding/decoding capabilities of the ReplicationMessage
+ * the innate encoding/decoding capabilities of the ReplicationMsg
* by using the getBytes() and generateMsg() methods of those classes.
*/
--
Gitblit v1.10.0